;;; zenirc-ignorance.el --- Get rid of people

;; Copyright (C) 1995 Per Persson

;; Author: Per Persson <pp@solace.mh.se>
;; Maintainer: pp@solace.mh.se
;; Keywords: zenirc, ignorance, extensions, n=F6ff
;; Created: 1995-04-24

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2, or (at your option)
;; any later version.
;;
;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.
;;
;; You should have received a copy of the GNU General Public License
;; along with this program; if not, you can either send email to this
;; program's maintainer or write to: The Free Software Foundation,
;; Inc.; 675 Massachusetts Avenue; Cambridge, MA 02139, USA.

;;; Commentary:

;;; Code:


(require 'zenirc)

(defvar zenirc-command-ignore-hook '(zenirc-command-ignore)
  "*Hook to call when a /ignore command is issude in ZenIRC.")

(defun zenirc-ignorance-install-message-catalogs ()
  (zenirc-lang-define-catalog 'english
    '((ignorance_list . "[info] Your current ignorance list: \"%s\"\n"))))

;; /ignore [+/- nickname]
;; shows ignorance list when executed without argument
(defun zenirc-command-ignore (proc parsedcmd)
  (let ((arg (cdr parsedcmd)))
  (if (and parsedcmd
	   (not (string=3D "" arg)))
      (if (string-match "+" (substring arg
				       (- (length arg)) 1))
	  (if (not (member (substring arg 1)
			   zenirc-ignorance-list))
	      (setq zenirc-ignorance-list (cons
					   (substring arg 1)
					   zenirc-ignorance-list)))
	(if (string-match "-" (substring arg
					 (- (length arg)) 1))
	    (setq zenirc-ignorance-list (delete
					 (substring arg 1)
					 zenirc-ignorance-list))))
    (zenirc-message proc 'ignorance_list
		    (mapconcat 'identity zenirc-ignorance-list
			       "\"   \"")))))


(provide 'zenirc-ignorance)

(zenirc-ignorance-install-message-catalogs)

;;; zenirc-ignorance.el ends here
